@@ -4,7 +4,7 @@ from typing import Generator, List, Optional
 import msgspec
 
 from pyrrhic.crypto.keys import MasterKey, decrypt_mac
-from pyrrhic.util import resticdatetime, resticdatetime_dec_hook
+from pyrrhic.util import maybe_decompress, resticdatetime, resticdatetime_dec_hook
 
 
 class Snapshot(msgspec.Struct):
@@ -23,6 +23,6 @@ class Snapshot(msgspec.Struct):
 def get_snapshot(key: MasterKey, repo_path: Path, snapshot_prefix: str) -> Generator[Snapshot, None, None]:
     dec = msgspec.json.Decoder(Snapshot, dec_hook=resticdatetime_dec_hook)
     for snapshot_path in (repo_path / "snapshots").glob(f"{snapshot_prefix}*"):
-        snapshot = dec.decode(decrypt_mac(key, snapshot_path.read_bytes()))
+        snapshot = dec.decode(maybe_decompress(decrypt_mac(key, snapshot_path.read_bytes())))
         snapshot.id = snapshot_path.name
         yield snapshot
