@@ -68,3 +68,7 @@ def test_ls(capfd, repository):
     for s in lines:
         path = Path(s)
         assert path.is_absolute()
+    with pytest.raises(ValueError, match="Index: invalid not found"):
+        ls("invalid", False)
+    with pytest.raises(ValueError, match="Prefix  matches multiple snapshots"):
+        ls("", False)
